@@ -23,10 +23,11 @@ PERIOD = "."
 
 def get_references(
     text: str,
-    book_groups: dict[str, tuple[Book, ...]] = None,
+    book_groups: dict[str, tuple[Book, ...]] | None = None,
 ) -> list[NormalizedReference]:
-    """Search the text for scripture references and return any that are found in a list
-    of normalized tuple references.
+    """Search the text for scripture references.
+
+    Return any scripture references that are found in a list of normalized references.
 
     :param text: String that may contain zero or more scripture references
     :type text: str
@@ -73,13 +74,11 @@ def normalize_reference(reference: str) -> list[NormalizedReference]:
         book_found = False
 
         for book in Book:
-            reference_match: Match[str] | None = re.search(
+            if reference_match := re.search(
                 book.regular_expression,
                 reference_without_books,
                 re.IGNORECASE,
-            )
-
-            if reference_match:
+            ):
                 start, end = reference_match.regs[0]
 
                 if start != 0 and not books:
